#[non_exhaustive]pub enum CreateTopicError {
Show 17 variants
BadRequestException(BadRequestException),
ClusterConnectivityException(ClusterConnectivityException),
ConflictException(ConflictException),
ControllerMovedException(ControllerMovedException),
ForbiddenException(ForbiddenException),
GroupSubscribedToTopicException(GroupSubscribedToTopicException),
InternalServerErrorException(InternalServerErrorException),
KafkaRequestException(KafkaRequestException),
KafkaTimeoutException(KafkaTimeoutException),
NotControllerException(NotControllerException),
ReassignmentInProgressException(ReassignmentInProgressException),
ServiceUnavailableException(ServiceUnavailableException),
TooManyRequestsException(TooManyRequestsException),
TopicExistsException(TopicExistsException),
UnauthorizedException(UnauthorizedException),
UnknownTopicOrPartitionException(UnknownTopicOrPartitionException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateTopicError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadRequestException(BadRequestException)
Returns information about an error.
ClusterConnectivityException(ClusterConnectivityException)
Returns information about an error.
ConflictException(ConflictException)
Returns information about an error.
ControllerMovedException(ControllerMovedException)
Returns information about an error.
ForbiddenException(ForbiddenException)
Returns information about an error.
GroupSubscribedToTopicException(GroupSubscribedToTopicException)
Returns information about an error.
InternalServerErrorException(InternalServerErrorException)
Returns information about an error.
KafkaRequestException(KafkaRequestException)
Returns information about an error.
KafkaTimeoutException(KafkaTimeoutException)
Returns information about an error.
NotControllerException(NotControllerException)
Returns information about an error.
ReassignmentInProgressException(ReassignmentInProgressException)
Returns information about an error.
Returns information about an error.
TooManyRequestsException(TooManyRequestsException)
Returns information about an error.
TopicExistsException(TopicExistsException)
Returns information about an error.
Returns information about an error.
UnknownTopicOrPartitionException(UnknownTopicOrPartitionException)
Returns information about an error.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateTopicError
impl CreateTopicError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateTopicError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateTopicError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_bad_request_exception(&self) -> bool
pub fn is_bad_request_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::BadRequestException.
Sourcepub fn is_cluster_connectivity_exception(&self) -> bool
pub fn is_cluster_connectivity_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::ClusterConnectivityException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::ConflictException.
Sourcepub fn is_controller_moved_exception(&self) -> bool
pub fn is_controller_moved_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::ControllerMovedException.
Sourcepub fn is_forbidden_exception(&self) -> bool
pub fn is_forbidden_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::ForbiddenException.
Sourcepub fn is_group_subscribed_to_topic_exception(&self) -> bool
pub fn is_group_subscribed_to_topic_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::GroupSubscribedToTopicException.
Sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::InternalServerErrorException.
Sourcepub fn is_kafka_request_exception(&self) -> bool
pub fn is_kafka_request_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::KafkaRequestException.
Sourcepub fn is_kafka_timeout_exception(&self) -> bool
pub fn is_kafka_timeout_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::KafkaTimeoutException.
Sourcepub fn is_not_controller_exception(&self) -> bool
pub fn is_not_controller_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::NotControllerException.
Sourcepub fn is_reassignment_in_progress_exception(&self) -> bool
pub fn is_reassignment_in_progress_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::ReassignmentInProgressException.
Returns true if the error kind is CreateTopicError::ServiceUnavailableException.
Sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::TooManyRequestsException.
Sourcepub fn is_topic_exists_exception(&self) -> bool
pub fn is_topic_exists_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::TopicExistsException.
Returns true if the error kind is CreateTopicError::UnauthorizedException.
Sourcepub fn is_unknown_topic_or_partition_exception(&self) -> bool
pub fn is_unknown_topic_or_partition_exception(&self) -> bool
Returns true if the error kind is CreateTopicError::UnknownTopicOrPartitionException.